==> Cosmos.uv5.13Diff.tar.gz: cosmos/Zmanagerp.h <==
#include "Zmaxdef.h"
c   Parameters   needed  for the Launcher.
c
c	(->	------------------------------------

	integer ErrorOut    !2 Error output logical  dev number.
	character*70  PrimaryFile  !1  Primary Spectrum data file (full or relative path)
	character*70  CutOffFile   !1  Geomagnetic cut-off file
	character*70  ContFile     !1  Job continuation information file  (full or relative path).
                                   !   default is "ContInfo".  This will be created when job
                                   !   is finished normally.
	character*70  SkeletonFile !1   Skeleton information file (full or relative path). created if Job =
                                   !    'skeleton'. Default is 'skeletonParam'.  This is the Namelist data
                                   !     referred by Cosmos automatically  if Job='flesh' is specified. For
                                   !     Job='flesh', you have to modify some part of  this file.
	character*10  Job          !1  What kind of job you are going to do.\newline
                                   !   =' ' (default).  nothing special.\newline
                                   !   ='skeleton'.  Makes skeleton. Later you can add AS, follow particles
                                   !        to a lower energy and/or to a deeper depth, by giving Job='flesh'.
                                   !        'skeletonParm' is automatically created.\newline
                                   !   ='flesh'. Using information created by Job='skeleton' and the 
                                   !             initial random number for each event, you can add AS,
                                   !             follow particles to a lower energy and/or to a deeper depth.
	                           !             The namelist parameters you give should be 'skeletonParam'
	                           !             with some necessary modification.
        character*70  SeedFile     !1   File to  contain the initial random numbers for those events to 
                                   !    which you want to flesh. You can create the file by calling
                                   !     cwriteSeed in a user hook routine (say, in chookEnEvent) at 
                                   !     skeleton making time. Default is 'Seed'.  For a normal run with
                                   !      Job=' ', if SeedFile is not ' ',  two integer initial random numbers
                                   !      and the event number are  automatically output on the speicfied disk file.
        integer       SeedFileDev  !2   logical device number of SeedFile.
	logical       Cont         !1  If T, continuation from a previous job is assumed. Contfile content is used.
	integer       InitRN       !1  Initial random number seed. 2 integers.
	integer       EventNo      !2  cumulative event number counter.
	integer       EventsInTheRun !2  Counter for event number in the run. Internal use.
	integer       DestEventNo    !1 2 integers: Final event no. to be generated and events to be generated
                                     !  in the current run.
	logical       Hidden         !1  Make T, if hidden parameters are to be written.
	integer	      TempDev	   !2  Logical Dev. number for temporary disk use.
	integer       PrevEventNo  !2  The event number already finished.  System use for Cont job.
	character*8   DeadLine     !1  The dead line before which the job should terminate.
                                   !   Should be given like '10.11.15' which means the nearest 10th, 11 O'clock,
                                   !   15 min.  Not used if Within has non zero value.  
        integer       Within       !1  The job should end within this minutes from now.  Default is 99999.
                                   !   If 0 is given,  DeadLine is used.
        real*8        BaseTime     !1  Rough cpu time needed for completing one event (say, for protons, or
                                   !   gamma rays) with energy BaseErg.  The cpu time estimation is based on 
                                   !   A * ( E1ry par nucleon )**BasePower / BaseErg * BaseTime, where A is mass number
                                   !  (for nucleus; otherwise 1).
        real*8        BaseErg      !2  See BaseTime.  The default is  1000 (GeV).
        real*8        BasePower    !2  See BaseTime.   Default is 1.0
        character*100 UserHookc    !2  array size is MAX_USERHOOKC=5 Usage is left for the user
        real*8        UserHookr    !2  array size is MAX_USERHOOKR=10 Usage is left for the user
        integer       UserHooki    !2  array size is MAX USERHOOKI=10 Usage is left for the user
        character*100 AtmosFile    !2  path to the atmospheric data as in 
                                   !        'Cosmos/Data/Atmos/stdatmos2.d'
c	<-)	-------------------------------------
	common /Zmanagerpc/
     *  BaseTime,  BaseErg, BasePower, Within, UserHookr(MAX_USERHOOKR),
     *  ErrorOut, Cont, InitRN(2), UserHooki(MAX_USERHOOKI),
     *  EventsInTheRun, DestEventNo(2), Hidden, TempDev, 
     *  PrevEventNo, SeedFileDev, EventNo


	common /Zmanagerpc2/ UserHookc(MAX_USERHOOKC), PrimaryFile,
     *  CutOffFile,  Job, ContFile, AtmosFile,
     *  SkeletonFile, SeedFile, DeadLine

==> Cosmos.uv5.55Diff.tar.gz: cosmos/Zmanagerp.h <==
#include "Zmaxdef.h"
c   Parameters   needed  for the Launcher.
c
c	(->	------------------------------------

	integer ErrorOut    !2 Error output logical  dev number.
	character*70  PrimaryFile  !1  Primary Spectrum data file (full or relative path)
	character*70  CutOffFile   !1  Geomagnetic cut-off file
	character*70  ContFile     !1  Job continuation information file  (full or relative path).
                                   !   default is "ContInfo".  This will be created when job
                                   !   is finished normally.
	character*70  GeomagFile   !2  IGRF or WMM file path which contains geomagnetic field expansion 
                                   !   coefficients.  Their format is the same one as given in their web 
                                   !   page.  If ' ' (default), Cosmos/Data/Geomag/igrf is used.
	character*70  SkeletonFile !1   Skeleton information file (full or relative path). created if Job =
                                   !    'skeleton'. Default is 'skeletonParam'.  This is the Namelist data
                                   !     referred by Cosmos automatically  if Job='flesh' is specified. For
                                   !     Job='flesh', you have to modify some part of  this file.
	character*10  Job          !1  What kind of job you are going to do.\newline
                                   !   =' ' (default).  nothing special.\newline
                                   !   ='skeleton'.  Makes skeleton. Later you can add AS, follow particles
                                   !        to a lower energy and/or to a deeper depth, by giving Job='flesh'.
                                   !        'skeletonParm' is automatically created.\newline
                                   !   ='flesh'. Using information created by Job='skeleton' and the 
                                   !             initial random number for each event, you can add AS,
                                   !             follow particles to a lower energy and/or to a deeper depth.
	                           !             The namelist parameters you give should be 'skeletonParam'
	                           !             with some necessary modification.
        character*70  SeedFile     !1   File to  contain the initial random numbers for those events to 
                                   !    which you want to flesh. You can create the file by calling
                                   !     cwriteSeed in a user hook routine (say, in chookEnEvent) at 
                                   !     skeleton making time. Default is 'Seed'.  For a normal run with
                                   !      Job=' ', if SeedFile is not ' ',  two integer initial random numbers
                                   !      and the event number are  automatically output on the speicfied disk file.
        integer       SeedFileDev  !2   logical device number of SeedFile.
	logical       Cont         !1  If T, continuation from a previous job is assumed. Contfile content is used.
	integer       InitRN       !1  Initial random number seed. 2 integers.
	integer       EventNo      !2  cumulative event number counter.(excluding discarded ones due to cutoff).
	integer       EventsInTheRun !2  Counter for event number in the run. Internal use.
                                     !          (excluding discarded ones due to cutoff).
	integer       DestEventNo    !1 2 integers: Final event no. to be generated and events to be generated
                                     !  in the current run.  If negative, their absolute is used and counting 
                                     !  includes discarded ones due to rigidity cutoff.
                                     !  If DestEventNo(2)=0, DestEventNo(1) is used. If negative, only
                                     !  DestEventNo(2) is checked to see events in the current run.
	logical       Hidden         !1  Make T, if hidden parameters are to be written.
	integer	      TempDev	   !2  Logical Dev. number for temporary disk use.
	integer       PrevEventNo  !2  The event number already finished.  System use for Cont job.
                                   !        (excluding discarded ones due to cutoff).
	character*8   DeadLine     !1  The dead line before which the job should terminate.
                                   !   Should be given like '10.11.15' which means the nearest 10th, 11 O'clock,
                                   !   15 min.  Not used if Within has non zero value.  
        integer       Within       !1  The job should end within this minutes from now.  Default is 99999.
                                   !   If 0 is given,  DeadLine is used.
        real*8        BaseTime     !1  Rough cpu time needed for completing one event (say, for protons, or
                                   !   gamma rays) with energy BaseErg.  The cpu time estimation is based on 
                                   !   A * ( E1ry par nucleon )**BasePower / BaseErg * BaseTime, where A is mass number
                                   !  (for nucleus; otherwise 1).
        real*8        BaseErg      !2  See BaseTime.  The default is  1000 (GeV).
        real*8        BasePower    !2  See BaseTime.   Default is 1.0
        character*100 UserHookc    !2  array size is MAX_USERHOOKC=5 Usage is left for the user
        real*8        UserHookr    !2  array size is MAX_USERHOOKR=10 Usage is left for the user
        integer       UserHooki    !2  array size is MAX USERHOOKI=10 Usage is left for the user
        character*100 AtmosFile    !2  path to the atmospheric data as in 
                                   !        'Cosmos/Data/Atmos/stdatmos2.d'
c	<-)	-------------------------------------
	common /Zmanagerpc/
     *  BaseTime,  BaseErg, BasePower, Within, UserHookr(MAX_USERHOOKR),
     *  ErrorOut, Cont, InitRN(2), UserHooki(MAX_USERHOOKI),
     *  EventsInTheRun, DestEventNo(2), Hidden, TempDev, 
     *  PrevEventNo, SeedFileDev, EventNo


	common /Zmanagerpc2/ UserHookc(MAX_USERHOOKC), PrimaryFile,
     *  CutOffFile,  Job, ContFile, AtmosFile, GeomagFile,
     *  SkeletonFile, SeedFile, DeadLine
